pub enum Meta {
Path(Path),
List(MetaList),
NameValue(MetaNameValue),
}Expand description
Content of a compile-time structured attribute.
Path
A meta path is like the test in #[test].
List
A meta list is like the derive(Copy) in #[derive(Copy)].
NameValue
A name-value meta is like the path = "..." in #[path = "sys/windows.rs"].
Syntax tree enum
This type is a syntax tree enum.
Variants
Path(Path)
List(MetaList)
A structured list within an attribute, like derive(Copy, Clone).
NameValue(MetaNameValue)
A name-value pair within an attribute, like feature = "nightly".
Implementations
Sourceimpl Meta
impl Meta
Sourcepub fn path(&self) -> &Path
pub fn path(&self) -> &Path
Returns the path that begins this structured meta item.
For example this would return the test in #[test], the derive in
#[derive(Copy)], and the path in #[path = "sys/windows.rs"].
Sourcepub fn require_path_only(&self) -> Result<&Path, Error>
pub fn require_path_only(&self) -> Result<&Path, Error>
Error if this is a Meta::List or Meta::NameValue.
Sourcepub fn require_list(&self) -> Result<&MetaList, Error>
pub fn require_list(&self) -> Result<&MetaList, Error>
Error if this is a Meta::Path or Meta::NameValue.
Sourcepub fn require_name_value(&self) -> Result<&MetaNameValue, Error>
pub fn require_name_value(&self) -> Result<&MetaNameValue, Error>
Error if this is a Meta::Path or Meta::List.